Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/jappix/jappix.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'server/functions.php')
-rw-r--r--server/functions.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/server/functions.php b/server/functions.php
index 7939f2ff..18d91d73 100644
--- a/server/functions.php
+++ b/server/functions.php
@@ -141,7 +141,7 @@ function readXML($type, $xmlns) {
return false;
}
// Creates a secure download context (StartSSL provider, used on Jappix.org which is the update source)
function requestContext($remote_url, $type = 'default', $opt = null) {
$options = array();
$url_parse = parse_url($remote_url);
@@ -149,7 +149,7 @@ function requestContext($remote_url, $type = 'default', $opt = null) {
$ca_path = JAPPIX_BASE.'/misc/certs/';
// Official update host?
- if($url_parse['scheme'] === 'https' && $url_parse['host'] === 'jappix.org') {
+ if($url_parse['scheme'] === 'https' && $url_parse['host'] === 'project.jappix.com') {
if($type === 'curl') {
curl_setopt($opt, CURLOPT_SSL_VERIFYPEER, TRUE);
curl_setopt($opt, CURLOPT_CAPATH, $ca_path);
@@ -141,7 +141,7 @@ function readXML($type, $xmlns) {
return false;
}
-// Creates a secure download context (StartSSL provider, used on Jappix.org which is the update source)
+// Creates a secure download context (StartSSL provider, used on Jappix.com which is the update source)
function requestContext($remote_url, $type = 'default', $opt = null) {
$options = array();